@@ -94,10 +94,8 @@ config_finalize (GObject *object)
 static void
 e_table_config_changed (ETableConfig *config, ETableState *state)
 {
-	g_return_if_fail (config != NULL);
 	g_return_if_fail (E_IS_TABLE_CONFIG (config));
 
-	
 	g_signal_emit(G_OBJECT(config), e_table_config_signals [CHANGED], 0, state);
 }
 
@@ -272,7 +270,7 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		}
 
 		/* Set the text */
-		gtk_combo_text_set_text (widgets [i].combo, text);
+		gal_combo_text_set_text (widgets [i].combo, text);
 
 		g_signal_handler_unblock (
 			widgets [i].radio_ascending,
@@ -372,8 +370,13 @@ setup_fields (ETableConfig *config)
 
 	if (config->temp_state) {
 		for (i = 0; i < config->temp_state->col_count; i++) {
-			e_table_subset_variable_add (config->shown_model, config->temp_state->columns[i]);
-			e_table_without_hide (config->available_model, GINT_TO_POINTER(config->temp_state->columns[i]));
+			gint j, idx;
+			for (j = 0, idx = 0; j < config->temp_state->columns[i]; j++)
+				if (!config->source_spec->columns[j]->disabled)
+					idx++;
+
+			e_table_subset_variable_add (config->shown_model, idx);
+			e_table_without_hide (config->available_model, GINT_TO_POINTER(idx));
 		}
 	}
 }
@@ -439,7 +442,7 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 					config->temp_state->sort_info, 0);
 			}
 			update_sort_and_group_config_dialog (config, is_sort);
-			continue;
+			break;
 
 		case GTK_RESPONSE_OK:
 			g_object_unref (config->state);
@@ -449,6 +452,7 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 			config_dialog_changed (config);
 			break;
 
+		case GTK_RESPONSE_DELETE_EVENT:
 		case GTK_RESPONSE_CANCEL:
 			g_object_unref (config->temp_state);
 			config->temp_state = 0;
@@ -488,7 +492,7 @@ do_fields_config_dialog (ETableConfig *config)
 			config_dialog_changed (config);
 			break;
 
-			/* CANCEL */
+		case GTK_RESPONSE_DELETE_EVENT:
 		case GTK_RESPONSE_CANCEL:
 			g_object_unref (config->temp_state);
 			config->temp_state = 0;
@@ -505,6 +509,7 @@ do_fields_config_dialog (ETableConfig *config)
 
 ETableMemoryStoreColumnInfo store_columns[] = {
 	E_TABLE_MEMORY_STORE_STRING,
+	E_TABLE_MEMORY_STORE_INTEGER,
 	E_TABLE_MEMORY_STORE_TERMINATOR
 };
 
@@ -524,7 +529,7 @@ create_global_store (ETableConfig *config)
 			continue;
 
 		text = g_strdup (dgettext (config->domain, config->source_spec->columns[i]->title));
-		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), -1, NULL, text);
+		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), -1, NULL, text, i);
 	}
 }
 
@@ -609,7 +614,7 @@ GtkWidget *e_table_proxy_gtk_combo_text_new (void);
 GtkWidget *
 e_table_proxy_gtk_combo_text_new (void)
 {
-	return gtk_combo_text_new (TRUE);
+	return gal_combo_text_new (TRUE);
 }
 
 #if 0
@@ -635,6 +640,17 @@ connect_button (ETableConfig *config, GladeXML *gui, const char *widget_name, GC
 	}
 }
 
+static gint
+get_source_model_col_index (ETableConfig *config, gint idx)
+{
+	gint visible_index, result;
+	ETableModel *src_model = E_TABLE_SUBSET (config->available_model)->source;
+
+        visible_index = e_table_subset_view_to_model_row (E_TABLE_SUBSET (config->available_model), idx);
+	
+	return GPOINTER_TO_INT (e_table_model_value_at (src_model, 1, visible_index));
+}
+
 static void
 sort_entry_changed (GtkEntry *entry, ETableConfigSortWidgets *sort)
 {
@@ -691,10 +707,10 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 		char buffer [80];
 
 		snprintf (buffer, sizeof (buffer), "sort-combo-%d", i + 1);
-		config->sort [i].combo = GTK_COMBO_TEXT (
+		config->sort [i].combo = GAL_COMBO_TEXT (
 			glade_xml_get_widget (gui, buffer));
 		gtk_widget_show (GTK_WIDGET (config->sort [i].combo));
-		gtk_combo_text_add_item (config->sort [i].combo, "", "");
+		gal_combo_text_add_item (config->sort [i].combo, "", "");
 
 		snprintf (buffer, sizeof (buffer), "frame-sort-%d", i + 1);
 		config->sort [i].frames = 
@@ -719,7 +735,7 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 		char *label = l->data;
 
 		for (i = 0; i < 4; i++){
-			gtk_combo_text_add_item (config->sort [i].combo,
+			gal_combo_text_add_item (config->sort [i].combo,
 						 dgettext (config->domain, label), label);
 		}
 	}
@@ -795,11 +811,11 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 		char buffer [80];
 
 		snprintf (buffer, sizeof (buffer), "group-combo-%d", i + 1);
-		config->group [i].combo = GTK_COMBO_TEXT (
+		config->group [i].combo = GAL_COMBO_TEXT (
 			glade_xml_get_widget (gui, buffer));
 		gtk_widget_show (GTK_WIDGET (config->group [i].combo));
 
-		gtk_combo_text_add_item (config->group [i].combo, "", "");
+		gal_combo_text_add_item (config->group [i].combo, "", "");
 
 		snprintf (buffer, sizeof (buffer), "frame-group-%d", i + 1);
 		config->group [i].frames = 
@@ -831,7 +847,7 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 		char *label = l->data;
 
 		for (i = 0; i < 4; i++){
-			gtk_combo_text_add_item (
+			gal_combo_text_add_item (
 				config->group [i].combo,
 				dgettext (config->domain, label), label);
 		}
@@ -877,7 +893,7 @@ config_button_add (GtkWidget *widget, ETableConfig *config)
 	config->temp_state->expansions = g_renew (double, config->temp_state->expansions, config->temp_state->col_count + count);
 	i = config->temp_state->col_count;
 	for (column = columns; column; column = column->next) {
-		config->temp_state->columns[i] = e_table_subset_view_to_model_row (E_TABLE_SUBSET (config->available_model), GPOINTER_TO_INT (column->data));
+		config->temp_state->columns[i] = get_source_model_col_index (config, GPOINTER_TO_INT (column->data));
 		config->temp_state->expansions[i] = config->source_spec->columns[config->temp_state->columns[i]]->expansion;
 		i++;
 	}
@@ -1166,7 +1182,10 @@ e_table_config_new (const char          *header,
 		return NULL;
 	}
 
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (config->dialog_toplevel),
+					   GTK_RESPONSE_APPLY, FALSE);
 	gtk_widget_show (config->dialog_toplevel);
+
 	return E_TABLE_CONFIG (config);
 }
 
